==> resin-4.0.59-src.tar.gz: resin-4.0.59/modules/kernel/src/com/caucho/config/inject/AnnotatedOverrideMap.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.config.inject;

import java.lang.reflect.Method;
import java.util.concurrent.ConcurrentHashMap;

import javax.enterprise.inject.spi.AnnotatedMethod;

import com.caucho.loader.EnvironmentLocal;

/**
 * InterceptorBean represents a Java interceptor
 */
public class AnnotatedOverrideMap
{
  private static final EnvironmentLocal<AnnotatedOverrideMap> _localMap 
    = new EnvironmentLocal<AnnotatedOverrideMap>();
  
  private ConcurrentHashMap<Method,AnnotatedMethod<?>> _methodMap
    = new ConcurrentHashMap<Method,AnnotatedMethod<?>>();

  public static AnnotatedOverrideMap create()
  {
    synchronized (AnnotatedOverrideMap.class) {
      AnnotatedOverrideMap map = _localMap.getLevel();
      
      if (map == null) {
        map = new AnnotatedOverrideMap();
        _localMap.set(map);
      }
      
      return map;
    }
  }
  
  public static void putMethod(Method method, AnnotatedMethod<?> annMethod)
  {
    create()._methodMap.put(method, annMethod);
  }
  
  public static AnnotatedMethod<?> getMethod(Method method)
  {
    AnnotatedOverrideMap map = _localMap.get();
    
    if (map != null)
      return map._methodMap.get(method);
    else
      return null;
  }
}

==> resin-4.0.65-src.tar.gz: resin-4.0.65/modules/kernel/src/com/caucho/config/inject/AnnotatedOverrideMap.java <==
/*
 * Copyright (c) 1998-2018 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.config.inject;

import java.lang.reflect.Method;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import javax.enterprise.inject.spi.AnnotatedMethod;

import com.caucho.loader.EnvironmentLocal;

/**
 * InterceptorBean represents a Java interceptor
 */
public class AnnotatedOverrideMap
{
  private static final EnvironmentLocal<AnnotatedOverrideMap> _localMap 
    = new EnvironmentLocal<AnnotatedOverrideMap>();
  
  private Map<Method,AnnotatedMethod<?>> _methodMap
    = new ConcurrentHashMap<Method,AnnotatedMethod<?>>();

  public static AnnotatedOverrideMap create()
  {
    synchronized (AnnotatedOverrideMap.class) {
      AnnotatedOverrideMap map = _localMap.getLevel();
      
      if (map == null) {
        map = new AnnotatedOverrideMap();
        _localMap.set(map);
      }
      
      return map;
    }
  }
  
  public static void putMethod(Method method, AnnotatedMethod<?> annMethod)
  {
    create()._methodMap.put(method, annMethod);
  }
  
  public static AnnotatedMethod<?> getMethod(Method method)
  {
    AnnotatedOverrideMap map = _localMap.get();
    
    if (map != null)
      return map._methodMap.get(method);
    else
      return null;
  }
}
